@@ -130,9 +130,10 @@ def _arg_name(args: Tuple[Any], kwargs: Dict[str, Any]) -> str:
         return name
 
     # get positional arguments which may specify argument name (strings starting with hyphens)
+    nd = [x for x in args if isinstance(x, str) and not x.startswith('-')]
     dd = [x for x in args if isinstance(x, str) and x.startswith('--')]
     sd = [x for x in args if isinstance(x, str) and x.startswith('-') and (x not in dd)]
-    _d = sd + dd
+    _d = nd + dd + sd
 
     # ensure there's at least one positional argument we could use to set the name.
     if not _d:
@@ -142,7 +143,7 @@ def _arg_name(args: Tuple[Any], kwargs: Dict[str, Any]) -> str:
         )
 
     # select the first item in the list, normalize the name and return it.
-    return _normalize_arg_name(_d[-1])
+    return _normalize_arg_name(_d[0])
 
 
 # ------------------------------------------------------------------------------------------------------------------------
